Documentation
¶
Overview ¶
Package payload provides interfaces and types for working with data payloads.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BasicPayload ¶
type BasicPayload struct {
// Data holds the byte data of the payload.
Data []byte
}
BasicPayload is a simple implementation of the MarshalerByte interface.
func (BasicPayload) Bytes ¶
func (p BasicPayload) Bytes() []byte
Bytes returns the byte representation of the BasicPayload. It implements the Bytes method of the MarshalerByte interface.
type MarshalerByte ¶
type MarshalerByte interface {
// Bytes returns the byte representation of the implementing type.
Bytes() []byte
}
MarshalerByte is an interface for types that can marshal themselves into a byte slice.
Click to show internal directories.
Click to hide internal directories.